Index: trunk/gsdl/bin/script/build
===================================================================
--- trunk/gsdl/bin/script/build	(revision 1969)
+++ trunk/gsdl/bin/script/build	(revision 1970)
@@ -135,5 +135,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "build: Builds a Greenstone collection (i.e. runs import.pl and buildcol.pl\n";
+    print STDERR "       then copies the resulting indexes to the correct place).\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -optionfile file        Get options from file, useful on systems where\n";
Index: trunk/gsdl/bin/script/buildcol.pl
===================================================================
--- trunk/gsdl/bin/script/buildcol.pl	(revision 1969)
+++ trunk/gsdl/bin/script/buildcol.pl	(revision 1970)
@@ -44,5 +44,7 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "buildcol.pl: Builds the indexes of a Greenstone collection.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number     0=none, 3=lots\n";
@@ -65,6 +67,8 @@
     print STDERR "   -out                  Filename or handle to print output status to.\n";
     print STDERR "                         The default is STDERR\n";
-    print STDERR "   -buildtype mg|mgpp    THis will override the config file setting. (default is mg)\n";
-    print STDERR "   -no_strip_html        Do not strip the html tags from the indexed text (only used for mgpp collections).\n\n";
+    print STDERR "   -buildtype mg|mgpp    This will override the config file setting.\n";
+    print STDERR "                         (default is mg)\n";
+    print STDERR "   -no_strip_html        Do not strip the html tags from the indexed text\n";
+    print STDERR "                         (only used for mgpp collections).\n\n";
 }
 
Index: trunk/gsdl/bin/script/cancel_build.pl
===================================================================
--- trunk/gsdl/bin/script/cancel_build.pl	(revision 1969)
+++ trunk/gsdl/bin/script/cancel_build.pl	(revision 1970)
@@ -47,5 +47,9 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "cancel_build.pl: Cancel a build in progress. This script is\n";
+    print STDERR "                 called from the collector and is not intended\n";
+    print STDERR "                 for general use.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -collectdir directory  Collection directory (defaults to " .
Index: trunk/gsdl/bin/script/classinfo.pl
===================================================================
--- trunk/gsdl/bin/script/classinfo.pl	(revision 1969)
+++ trunk/gsdl/bin/script/classinfo.pl	(revision 1970)
@@ -41,17 +41,13 @@
 
 sub print_usage {
-    print STDERR "
-  usage: $0 [options] classifier
-
-  options:
-   -collect collection-name  Giving a collection name will make 
-                             classinfo.pl look in
-                             collect/collection-name/perllib/classify
-                             first. If it doesn't find it there it will
-                             look in the general perllib/classify directory.
-
-";
+    print STDERR "\n";
+    print STDERR "classinfo.pl: Prints information about a classifier.\n\n";
+    print STDERR "  usage: $0 [options] classifier\n\n";
+    print STDERR "  options:\n";
+    print STDERR "   -collect collection-name  Giving a collection name will make\n";
+    print STDERR "         classinfo.pl look in collect/collection-name/perllib/classify\n";
+    print STDERR "         first. If it doesn't find it there it will look in the general\n";
+    print STDERR "         perllib/classify directory.\n\n";
 }
-
 
 &main ();
Index: trunk/gsdl/bin/script/cleantmp.pl
===================================================================
--- trunk/gsdl/bin/script/cleantmp.pl	(revision 1969)
+++ trunk/gsdl/bin/script/cleantmp.pl	(revision 1970)
@@ -39,6 +39,9 @@
 
 sub print_usage {
+    print STDERR "\n";
+    print STDERR "cleantmp.pl: Cleans up the Greenstone tmp directory by deleting anything\n";
+    print STDERR "             more than -expire_days days old.\n\n";
     print STDERR "\n  usage: $0 [options]\n\n";
-    print STDERR "  oprions:\n";
+    print STDERR "  options:\n";
     print STDERR "   -expire_days number   The number of days old information in the tmp\n";
     print STDERR "                         directory must be before it is removed (defaults\n";
Index: trunk/gsdl/bin/script/create_distributions.pl
===================================================================
--- trunk/gsdl/bin/script/create_distributions.pl	(revision 1969)
+++ trunk/gsdl/bin/script/create_distributions.pl	(revision 1970)
@@ -64,5 +64,7 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options]\n\n";
+    print STDERR "\n";
+    print STDERR "create_distributions.pl: Packages up Greenstone distributions.\n\n";
+    print STDERR "  usage: $0 [options]\n\n";
     print STDERR "  options:\n";
     print STDERR "   -version_num           version number of distribution (x.xx)\n";
Index: trunk/gsdl/bin/script/delcol.pl
===================================================================
--- trunk/gsdl/bin/script/delcol.pl	(revision 1969)
+++ trunk/gsdl/bin/script/delcol.pl	(revision 1970)
@@ -35,5 +35,7 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "delcol.pl: Deletes (forever) a collection.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -f                     Force deletion of collection without prompting\n\n";
Index: trunk/gsdl/bin/script/filecopy.pl
===================================================================
--- trunk/gsdl/bin/script/filecopy.pl	(revision 1969)
+++ trunk/gsdl/bin/script/filecopy.pl	(revision 1970)
@@ -40,4 +40,6 @@
 
 sub print_usage {
+    print STDERR "\n";
+    print STDERR "filecopy.pl: Recursively copies files into a collections import directory.\n\n";
     print STDERR "\n  usage: $0 [options] [directories] collection-name\n\n";
 
@@ -45,6 +47,6 @@
     print STDERR "   -collectdir directory   Collection directory (defaults to " .
 	&util::filename_cat ($ENV{'GSDLHOME'}, "collect") . ")\n";
-    print STDERR "   -out                  Filename or handle to print output status to.\n";
-    print STDERR "                         The default is STDERR\n\n";
+    print STDERR "   -out                    Filename or handle to print output status to.\n";
+    print STDERR "                           The default is STDERR\n\n";
 }
 
Index: trunk/gsdl/bin/script/gsConvert.pl
===================================================================
--- trunk/gsdl/bin/script/gsConvert.pl	(revision 1969)
+++ trunk/gsdl/bin/script/gsConvert.pl	(revision 1970)
@@ -49,6 +49,9 @@
 sub print_usage
 {
-    print STDERR "Usage: $0 [options] filename\n";
-    print STDERR "Options are:\n\t-type\tdoc|pdf\n\t-output\thtml|text\n";
+    print STDERR "\n";
+    print STDERR "gsConvert.pl: Converts documents in a range of formats to html\n";
+    print STDERR "              or text using third-party programs.\n\n";
+    print STDERR "  usage: $0 [options] filename\n";
+    print STDERR "  options:\n\t-type\tdoc|pdf\n\t-output\thtml|text\n";
     print STDERR "\t-timeout\t<max cpu seconds>\n";
     exit(1);
Index: trunk/gsdl/bin/script/gsdlinfo.pl
===================================================================
--- trunk/gsdl/bin/script/gsdlinfo.pl	(revision 1969)
+++ trunk/gsdl/bin/script/gsdlinfo.pl	(revision 1970)
@@ -36,4 +36,11 @@
 use parsargv;
 use colcfg;
+
+if (scalar(@ARGV) && $ARGV[0] eq "--help") {
+    print STDERR "\n";
+    print STDERR "gsdlinfo.pl: Prints information on any Greenstone collections\n";
+    print STDERR "             found on the local file system.\n\n";
+    exit;
+}
 
 
Index: trunk/gsdl/bin/script/import.pl
===================================================================
--- trunk/gsdl/bin/script/import.pl	(revision 1969)
+++ trunk/gsdl/bin/script/import.pl	(revision 1970)
@@ -48,5 +48,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "import.pl: Converts documents in collections -importdir directory into\n";
+    print STDERR "           gml documents which are written to the -archivedir directory.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number      0=none, 3=lots\n";
Index: trunk/gsdl/bin/script/makemapfile.pl
===================================================================
--- trunk/gsdl/bin/script/makemapfile.pl	(revision 1969)
+++ trunk/gsdl/bin/script/makemapfile.pl	(revision 1970)
@@ -67,8 +67,11 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options]\n\n";
+    print STDERR "\n";
+    print STDERR "makemapfile.pl: Creates unicode map (.ump) files from plain\n";
+    print STDERR "                text code pages.\n\n";
+    print STDERR "  usage: $0 [options]\n\n";
     print STDERR "  options:\n";
     print STDERR "   -encoding name\n";
-    print STDERR "   -mapfile  text file from which to create binary\n\n";
+    print STDERR "   -mapfile  text file from which to create binary ump file\n\n";
 }
 
Index: trunk/gsdl/bin/script/mirror.pl
===================================================================
--- trunk/gsdl/bin/script/mirror.pl	(revision 1969)
+++ trunk/gsdl/bin/script/mirror.pl	(revision 1970)
@@ -37,5 +37,5 @@
 #
 # To use w3mirror, the configuration file must be in etc/w3mir.cfg.
-# To use GNU wget, the configuartion file (i.e. a wgetrc file) must
+# To use GNU wget, the configuration file (i.e. a wgetrc file) must
 # be in etc/wget.cfg and a file of the URLs to read in etc/wget.url
 
@@ -57,5 +57,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "mirror.pl: Uses w3mir or wget to sync a collections import data\n";
+    print STDERR "           with a website.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number      0=none, 3=lots\n";
Index: trunk/gsdl/bin/script/mkcol.pl
===================================================================
--- trunk/gsdl/bin/script/mkcol.pl	(revision 1969)
+++ trunk/gsdl/bin/script/mkcol.pl	(revision 1970)
@@ -43,5 +43,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "mkcol.pl: Creates the directory structure for a new\n";
+    print STDERR "          Greenstone collection.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -optionfile file    Get options from file, useful on systems where\n";
Index: trunk/gsdl/bin/script/newsrc.pl
===================================================================
--- trunk/gsdl/bin/script/newsrc.pl	(revision 1969)
+++ 	(revision )
@@ -1,118 +1,0 @@
-#!/usr/bin/perl -w
-
-###########################################################################
-#
-# newsrc.pl -- creates new blank source files
-# A component of the Greenstone digital library software
-# from the New Zealand Digital Library Project at the 
-# University of Waikato, New Zealand.
-#
-# Copyright (C) 1999 New Zealand Digital Library Project
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-###########################################################################
-
-foreach $filename (@ARGV) {
-    if (-e "$filename.cpp") {
-	print STDERR "$filename.cpp already exists\n";
-	next;
-    }
-    if (-e "$filename.h") {
-	print STDERR "$filename.h already exists\n";
-	next;
-    }
-
-    $upperfilename = $filename;
-    $upperfilename =~ tr/a-z/A-Z/;
-    $upperfilename =~ s/[^A-Z]/_/g;
-
-    print STDERR "Creating $filename.cpp\n";
-
-    open (CPPFILE, ">$filename.cpp") || die "Couldn't write $filename.cpp";
-    
-    print CPPFILE "/**********************************************************************\n";
-    print CPPFILE " *\n";
-    print CPPFILE " * $filename.cpp -- \n";
-    print CPPFILE " * A component of the Greenstone digital library software\n";
-    print CPPFILE " * from the New Zealand Digital Library Project at the\n";
-    print CPPFILE " * University of Waikato, New Zealand.\n";
-    print CPPFILE " *\n";
-    print CPPFILE " * Copyright (C) 2000  The New Zealand Digital Library Project\n";
-    print CPPFILE " *\n";
-    print CPPFILE " * This program is free software; you can redistribute it and/or modify\n";
-    print CPPFILE " * it under the terms of the GNU General Public License as published by\n";
-    print CPPFILE " * the Free Software Foundation; either version 2 of the License, or\n";
-    print CPPFILE " * (at your option) any later version.\n";
-    print CPPFILE " *\n";
-    print CPPFILE " * This program is distributed in the hope that it will be useful,\n";
-    print CPPFILE " * but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
-    print CPPFILE " * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
-    print CPPFILE " * GNU General Public License for more details.\n";
-    print CPPFILE " *\n";
-    print CPPFILE " * You should have received a copy of the GNU General Public License\n";
-    print CPPFILE " * along with this program; if not, write to the Free Software\n";
-    print CPPFILE " * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n";
-    print CPPFILE " *\n";
-    print CPPFILE " *********************************************************************/\n";
-    print CPPFILE "\n";
-    print CPPFILE "\n";
-    print CPPFILE "#include \"$filename.h\"\n";
-    print CPPFILE "\n";
-
-    close (CPPFILE);
-
-
-    print STDERR "Creating $filename.h\n";
-
-    open (HFILE, ">$filename.h") || die "Couldn't write $filename.h";
-
-    print HFILE "/**********************************************************************\n";
-    print HFILE " *\n";
-    print HFILE " * $filename.h -- \n";
-    print HFILE " * A component of the Greenstone digital library software\n";
-    print HFILE " * from the New Zealand Digital Library Project at the\n";
-    print HFILE " * University of Waikato, New Zealand.\n";
-    print HFILE " *\n";
-    print HFILE " * Copyright (C) 2000  The New Zealand Digital Library Project\n";
-    print HFILE " *\n";
-    print HFILE " * This program is free software; you can redistribute it and/or modify\n";
-    print HFILE " * it under the terms of the GNU General Public License as published by\n";
-    print HFILE " * the Free Software Foundation; either version 2 of the License, or\n";
-    print HFILE " * (at your option) any later version.\n";
-    print HFILE " *\n";
-    print HFILE " * This program is distributed in the hope that it will be useful,\n";
-    print HFILE " * but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
-    print HFILE " * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
-    print HFILE " * GNU General Public License for more details.\n";
-    print HFILE " *\n";
-    print HFILE " * You should have received a copy of the GNU General Public License\n";
-    print HFILE " * along with this program; if not, write to the Free Software\n";
-    print HFILE " * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n";
-    print HFILE " *\n";
-    print HFILE " *********************************************************************/\n";
-    print HFILE "\n";
-    print HFILE "\n";
-    print HFILE "\#ifndef ${upperfilename}_H\n";
-    print HFILE "\#define ${upperfilename}_H\n";
-    print HFILE "\n";
-    print HFILE "\n";
-    print HFILE "\n";
-    print HFILE "\n";
-    print HFILE "\#endif\n";
-
-    close (HFILE);
-}
-
Index: trunk/gsdl/bin/script/perlcalc.pl
===================================================================
--- trunk/gsdl/bin/script/perlcalc.pl	(revision 1969)
+++ 	(revision )
@@ -1,5 +1,0 @@
-#! /usr/local/bin/perl5 -w
-
-while (defined($line=<STDIN>)) {
-	print eval($line), "\n";
-}
Index: trunk/gsdl/bin/script/pluginfo.pl
===================================================================
--- trunk/gsdl/bin/script/pluginfo.pl	(revision 1969)
+++ trunk/gsdl/bin/script/pluginfo.pl	(revision 1970)
@@ -42,5 +42,7 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] plugin\n\n";
+    print STDERR "\n";
+    print STDERR "pluginfo.pl: Prints information about a plugin.\n\n";
+    print STDERR "  usage: $0 [options] plugin\n\n";
     print STDERR "  options:\n";
     print STDERR "   -collect collection-name  Giving a collection name will make pluginfo.pl\n";
Index: trunk/gsdl/bin/script/sendmail.pl
===================================================================
--- trunk/gsdl/bin/script/sendmail.pl	(revision 1969)
+++ trunk/gsdl/bin/script/sendmail.pl	(revision 1970)
@@ -48,5 +48,7 @@
 		     'smtp/.*', \$smtp,
 		     'msgfile/.*/', \$msgfile)) {
-    print STDERR "\n  usage: $0 [options]\n\n";
+    print STDERR "\n";
+    print STDERR "sendmail.pl: A simple platform independant mail sending program.\n\n";
+    print STDERR "  usage: $0 [options]\n\n";
     print STDERR "  options:\n";
     print STDERR "   -to addr      Comma separated list of mail recipients\n";
Index: trunk/gsdl/bin/script/togb.pl
===================================================================
--- trunk/gsdl/bin/script/togb.pl	(revision 1969)
+++ 	(revision )
@@ -1,58 +1,0 @@
-#!/usr/bin/perl -w
-
-###########################################################################
-#
-# togb.pl -- converts to GB
-#
-# Copyright (C) 1999 DigiLib Systems Limited, NZ.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-###########################################################################
-
-BEGIN {
-    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
-    unshift (@INC, "$ENV{'GSDLHOME'}/perllib");
-}
-
-use unicode;
-use multiread;
-use parsargv;
-
-
-$encoding = "utf8";
-if (!parsargv::parse(\@ARGV, 
-		     'unicode', \$unicode,
-		     'iso_8859_1', \$iso_8859_1,
-		     'gb', \$gb)) {
-    print STDERR "\n  usage: $0 [options]\n\n";
-    print STDERR "  options:\n";
-    print STDERR "   -unicode    input is in utf-8 or unicode (default)\n";
-    print STDERR "   -iso_8859_1 input is in extended ascii (ISO-8859-1 Latin 1)\n";
-    print STDERR "   -gb         input is in GB or GBK (simplified Chinese)\n\n";
-    die "\n";
-}
-
-$encoding = "utf8" if $unicode;
-$encoding = "iso_8859_1" if $iso_8859_1;
-$encoding = "gb" if $gb;
-
-$reader = new multiread ();
-$reader->set_handle ('main::STDIN');
-$reader->set_encoding ($encoding);
-$line = "";
-while (defined ($line = $reader->read_line())) {
-    print &gb::unicode2gb (&unicode::utf82unicode ($line));
-}
Index: trunk/gsdl/bin/script/touc.pl
===================================================================
--- trunk/gsdl/bin/script/touc.pl	(revision 1969)
+++ 	(revision )
@@ -1,78 +1,0 @@
-#!/usr/bin/perl -w
-
-###########################################################################
-#
-# touc.pl -- converts to unicode
-#
-# Copyright (C) 1999 DigiLib Systems Limited, NZ.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-###########################################################################
-
-BEGIN {
-    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
-    unshift (@INC, "$ENV{'GSDLHOME'}/perllib");
-}
-
-use unicode;
-use multiread;
-use parsargv;
-
-
-$encoding = "utf8";
-if (!parsargv::parse(\@ARGV, 
-		     'unicode', \$unicode,
-		     'iso_8859_1', \$iso_8859_1,
-		     'iso_8859_6', \$iso_8859_6,
-		     'windows_1256', \$windows_1256,
-		     'gb', \$gb)) {
-    print STDERR "\n  usage: $0 [options]\n\n";
-    print STDERR "  options:\n";
-    print STDERR "   -unicode      input is in utf-8 or unicode (default)\n";
-    print STDERR "   -iso_8859_1   input is in extended ascii (ISO-8859-1 Latin 1)\n";
-    print STDERR "   -iso_8859_6   input is in 8 bit Arabic (ISO-8859-6)\n";
-    print STDERR "   -windows_1256 input is in Windows 1256 (Arabic)\n";
-    print STDERR "   -gb           input is in GB or GBK (simplified Chinese)\n\n";
-    die "\n";
-}
-
-$encoding = "utf8" if $unicode;
-$encoding = "iso_8859_1" if $iso_8859_1;
-$encoding = "iso_8859_6" if $iso_8859_6;
-$encoding = "windows_1256" if $windows_1256;
-$encoding = "gb" if $gb;
-
-
-if ($ENV{'GSDLOS'} =~ /windows/i) {
-    binmode (STDOUT); # silly windows
-}
-
-# output in little endian
-print "\xff\xfe";
-
-$reader = new multiread ();
-$reader->set_handle ('main::STDIN');
-$reader->set_encoding ($encoding);
-$line = "";
-$ucline = [];
-while (defined ($line = $reader->read_line())) {
-    $ucline = &unicode::utf82unicode ($line);
-    foreach $c (@$ucline) {
-	$c1 = chr (int ($c / 256));
-	$c2 = chr (int ($c % 256));
-	print "$c2$c1";
-    }
-}
Index: trunk/gsdl/bin/script/toutf8.pl
===================================================================
--- trunk/gsdl/bin/script/toutf8.pl	(revision 1969)
+++ 	(revision )
@@ -1,64 +1,0 @@
-#!/usr/bin/perl -w
-
-###########################################################################
-#
-# toutf8.pl -- converts to utf8
-#
-# Copyright (C) 1999 DigiLib Systems Limited, NZ.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-###########################################################################
-
-BEGIN {
-    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
-    unshift (@INC, "$ENV{'GSDLHOME'}/perllib");
-}
-
-use unicode;
-use multiread;
-use parsargv;
-
-
-$encoding = "utf8";
-if (!parsargv::parse(\@ARGV, 
-		     'unicode', \$unicode,
-		     'iso_8859_1', \$iso_8859_1,
-		     'iso_8859_6', \$iso_8859_6,
-		     'windows_1256', \$windows_1256,
-		     'gb', \$gb)) {
-    print STDERR "\n  usage: $0 [options]\n\n";
-    print STDERR "  options:\n";
-    print STDERR "   -unicode      input is in utf-8 or unicode (default)\n";
-    print STDERR "   -iso_8859_1   input is in extended ascii (ISO-8859-1 Latin 1)\n";
-    print STDERR "   -iso_8859_6   input is in 8 bit Arabic (ISO-8859-6)\n";
-    print STDERR "   -windows_1256 input is in Windows 1256 (Arabic)\n";
-    print STDERR "   -gb           input is in GB or GBK (simplified Chinese)\n\n";
-    die "\n";
-}
-
-$encoding = "utf8" if $unicode;
-$encoding = "iso_8859_1" if $iso_8859_1;
-$encoding = "iso_8859_6" if $iso_8859_6;
-$encoding = "windows_1256" if $windows_1256;
-$encoding = "gb" if $gb;
-
-$reader = new multiread ();
-$reader->set_handle ('main::STDIN');
-$reader->set_encoding ($encoding);
-$line = "";
-while (defined ($line = $reader->read_line())) {
-    print $line;
-}
Index: trunk/gsdl/bin/script/translate.pl
===================================================================
--- trunk/gsdl/bin/script/translate.pl	(revision 1969)
+++ trunk/gsdl/bin/script/translate.pl	(revision 1970)
@@ -92,5 +92,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] macrofile\n\n";
+    print STDERR "\n";
+    print STDERR "translate.pl: Uses gimp to generate any images required by a\n";
+    print STDERR "              Greenstone macro file.\n\n";
+    print STDERR "  usage: $0 [options] macrofile\n\n";
     print STDERR "  options:\n";
     print STDERR "   -save_orig_file       edited macrofile will be written to\n";
Index: trunk/gsdl/bin/script/unindex.pl
===================================================================
--- trunk/gsdl/bin/script/unindex.pl	(revision 1969)
+++ trunk/gsdl/bin/script/unindex.pl	(revision 1970)
@@ -59,5 +59,7 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options]\n\n";
+    print STDERR "\n";
+    print STDERR "unindex.pl: Attempts to generate gml files from a built Greenstone index.\n\n";
+    print STDERR "  usage: $0 [options]\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number      0=none, 3=lots\n";
Index: trunk/gsdl/bin/script/update.pl
===================================================================
--- trunk/gsdl/bin/script/update.pl	(revision 1969)
+++ trunk/gsdl/bin/script/update.pl	(revision 1970)
@@ -55,5 +55,8 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options] collection-name\n\n";
+    print STDERR "\n";
+    print STDERR "update.pl: Updates a collection if it has been set up to mirror\n";
+    print STDERR "           a website. Calls mirror.pl to do the mirroring.\n\n";
+    print STDERR "  usage: $0 [options] collection-name\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number      0=none, 3=lots\n";
Index: trunk/gsdl/bin/script/urlcopy.pl
===================================================================
--- trunk/gsdl/bin/script/urlcopy.pl	(revision 1969)
+++ 	(revision )
@@ -1,183 +1,0 @@
-#!/usr/bin/perl -w
-
-###########################################################################
-#
-# urlcopy.pl --
-# A component of the Greenstone digital library software
-# from the New Zealand Digital Library Project at the 
-# University of Waikato, New Zealand.
-#
-# Copyright (C) 1999 New Zealand Digital Library Project
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-###########################################################################
-
-
-# This program will download the specified urls (http:, ftp: and file:)
-
-BEGIN {
-    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
-    unshift (@INC, "$ENV{'GSDLHOME'}/perllib");
-
-    unshift (@INC, "$ENV{'GSDLHOME'}/perllib/cpan/lib");
-    $ENV{'PATH'} = "$ENV{'GSDLHOME'}/perllib/cpan/bin:$ENV{'PATH'}";
-}
-
-use util;
-use File::Basename;
-
-sub print_usage
-{
-    print STDERR "\n  usage: $0 [urls] collection-name\n\n";
-}
-
-sub main
-{
-    if (scalar(@ARGV)<2)
-    {
-	print_usage();
-	exit(1);
-    }
-
-    my $dirname = pop(@ARGV);
-    my $full_importname 
-	= &util::filename_cat($ENV{'GSDLHOME'},"collect",$dirname,"import");
-
-    mkdir ($full_importname, 0777) unless -e $full_importname;
-
-    # split argv into 3 lists: http, ftp and file
-    my (@http,@ftp,@file) = ((),(),());
-    my $a;
-    foreach $a (@ARGV)
-    {
-	$a =~ s/^\"//;
-	$a =~ s/\"$//;
-
-	if ($a =~ m/^http:/i)
-	{
-	    push(@http,$a);
-	}
-	elsif ($a =~ m/^ftp:/i)
-	{
-	    push(@ftp,$a);
-	}
-	elsif ($a =~ m/^file:/i)
-	{
-	    push(@file,$a);
-	}
-	else
-	{
-	    print STDERR "URL argument not supported: $a\n";
-	    print STDERR "Ingoring argument.\n";
-	}
-    }
-    
-    if (scalar(@http)>0)
-    {
-	my $w3mircfg_filename
-	    = &util::filename_cat($ENV{'GSDLHOME'},"tmp","$dirname.w3mir");
-
-	# create cfg file
-	open(CFGOUT,">$w3mircfg_filename")
-	    || die "Unable to open $w3mircfg_filename: $!";
-	print CFGOUT "Options: recurse\n\n";
-	
-	my $first = 1;
-	my $a;	
-	foreach $a (@http)
-	{
-	    my $src_url = $a;
-	    my $dst_dir = $a;
-	    $dst_dir =~ s/^http://i;
-	    $dst_dir = &util::filename_cat($full_importname,$dst_dir);
-
-	    if ($src_url !~ m/\/$/)
-	    {
-		# last name is a file => strip off filename
-		$dst_dir = &File::Basename::dirname($dst_dir);
-	    }
-	    if ($first)
-	    {
-		print CFGOUT "URL:        $src_url $dst_dir\n";
-		$first = 0;
-	    }
-	    else
-	    {
-		print CFGOUT "Also-queue: $src_url $dst_dir\n";
-	    }
-	}	    
-	print CFGOUT "\nFixup: run\n";
-	close(CFGOUT);
-
-	my $cmd = "cd $full_importname; ";
-	$cmd .= "w3mir.pl -cfgfile $w3mircfg_filename";
-
-	my $status = system($cmd);
-	$status /= 256;
-	if ($status != 0)
-	{
-	    print STDERR "An error was encountered executing: $cmd\n";
-	    exit($status);
-	}
-    }
-
-    if (scalar(@ftp)>0)
-    {
-	my $cmd = "cd $full_importname; ";
-	$cmd .= "ncftp ";
-	my $a;
-	foreach $a (@ftp)
-	{
-	    $a = "$a/" if ($a !~ m/\/$/);
-	    $cmd .= " \"$a/*\"";
-	}
-	my $status = system($cmd);
-	$status /= 256;
-	if ($status != 0)
-	{
-	    print STDERR "An error was encountered executing: $cmd\n";
-	    exit($status);
-	}
-
-    }
-
-    if (scalar(@file)>0)
-    {
-	my $cmd = "filedownload.pl";
-	my $a;
-	foreach $a (@file)
-	{
-	    $cmd .= " \"$a\"";
-	}
-	$cmd .= " $dirname";
-
-	my $status = system($cmd);
-	$status /= 256;
-	if ($status != 0)
-	{
-	    print STDERR "An error was encountered executing: $cmd\n";
-	    exit($status);
-	}
-    }
-
-    return 0;
-}
-
-&main();
-
-
-
-

Index: trunk/gsdl/bin/script/nightly.pl
===================================================================
--- trunk/gsdl/bin/script/nightly.pl	(revision 1969)
+++ trunk/gsdl/bin/script/nightly.pl	(revision 1970)
@@ -28,5 +28,5 @@
 
 
 # This program will find all thecollections under $GSDLHOME/collect
 # and use the update.pl script to update them all.  It should be run
 # every night to keep mirror collections up-to-date.
@@ -50,5 +50,9 @@
 
 sub print_usage {
-    print STDERR "\n  usage: $0 [options]\n\n";
+    print STDERR "\n";
+    print STDERR "nightly.pl: Attempts to update all Greenstone collections found on\n";
+    print STDERR "            the local filesystem by calling update.pl for each of\n";
+    print STDERR "            them.\n\n";
+    print STDERR "  usage: $0 [options]\n\n";
     print STDERR "  options:\n";
     print STDERR "   -verbosity number      0=none, 3=lots\n";
@@ -100,7 +104,2 @@
 
 }
-
-
-
-
-
@@ -28,5 +28,5 @@
 
 
-# This program will find all thecollections under $GSDLHOME/collect
+# This program will find all the collections under $GSDLHOME/collect
 # and use the update.pl script to update them all.  It should be run
 # every night to keep mirror collections up-to-date.